## 5.0.4.1 (2022-12-02)

[stubsabot] Mark chardet as obsolete since 5.1.0 (#9318)

Release: https://pypi.org/pypi/chardet/5.1.0
Homepage: https://github.com/chardet/chardet
Diff: https://github.com/chardet/chardet/compare/5.0.0...5.1.0

Co-authored-by: stubsabot <>

## 5.0.4 (2022-08-10)

Remove a few unused `TypedDict`s (#8522)

## 5.0.3 (2022-07-25)

Add missing `__version__` to `chardet.__init__` (#8401)

## 5.0.2 (2022-07-12)

Import `Match` and `Pattern` from `re`, not `typing` (#8277)

## 5.0.1 (2022-06-25)

chardet: improve stubs (#8155)

## 5.0.0 (2022-06-25)

[stubsabot] Bump chardet to 5.0.* (#8150)

Co-authored-by: hauntsaninja <>

## 4.0.4 (2022-04-27)

Drop Python 2 support from chardet (#7708)

## 4.0.2 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 4.0.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 4.0.0 (2021-09-19)

Update third-party package versions (#5996)

